<?php
/*
 * Plugin Name: Kid Info Widget
 * Version: 0.5
 * Plugin URI: http://www.vanvendeloo.net
 * Description: Developed to be able to display information about one or more kids in the widget area's.
 * Author: Mike van Vendeloo
 * Author URI: http://mike.vanvendeloo.net
 */

/*
 This widget was developed for my sister-in-law, so she could display some information and a picture of her kids on her Wordpress site.
*/

add_option("kid_info_widget_version", "0.5");

class KidInfoWidget extends WP_Widget
{
 /**
  * Declares the KidInfoWidget class.
  *
  */
    function KidInfoWidget(){
      $widget_ops = array('classname' => 'kid_info_widget', 'description' => __( "Widget to display information about a child.") );
      /*$control_ops = array('width' => 300, 'height' => 300);*/
      $control_ops = array();

      $current_version = get_option('kid_info_widget_version', '0.5');

      $this->WP_Widget('KidInfoWidget', __('Kid Info Widget'), $widget_ops, $control_ops);
    }

  /**
    * Displays the Widget
    *
    */
    function widget($args, $instance){
      extract($args);
      $name = apply_filters('widget_title', empty($instance['name']) ? '&nbsp;' : $instance['name']);
      $content = $instance['content'];
      $date_of_birth = $instance['date_of_birth'];
      $time_of_birth = $instance['time_of_birth'];
      $birth_weight = $instance['birth_weight'];
      $birth_length = $instance['birth_length'];
      $current_weight = $instance['current_weight'];
      $current_length = $instance['current_length'];
      $show_birth_weight = $instance['show_birth_weight'];
      $show_birth_length = $instance['show_birth_weight'];
      $show_current_weight = $instance['show_current_weight'];
      $show_current_length = $instance['show_current_length'];

      $photo_url =$instance['photo_url']; 
      $photo_width = $instance['photo_width'];
      
      if($photo_width=="") {
          $photo_width = 75;
      }
      # Before the widget
      echo $before_widget;

      # The name of the child is used as a title
      echo $before_title . $name . $after_title;

      # get current date
      $now = mktime();     // Today's date.
      $birthDate = strtotime($date_of_birth." ".$time_of_birth.":00");
      $difference=dateDifference($birthDate,$now);
      $nrWeeksPassed = floor(($now-$birthDate) /  604800);
      $age = calculateAge($birthDate);
      $customstyle="kidinfo";
      if($instance['customstyle'] != '') {
	$customstyle=$customstyle." ".$instance['customstyle'];
      }
      echo '<div class="'.$customstyle.'">';
      echo "<table cellspacing='0' cellpadding='0'>";
      echo "<tr>";
      if($photo_url != '') {
          echo "<td rowspan='4'><img src='".$photo_url."' width='".$photo_width."' class='kidinfo_thumbnail' /></td>";
      }
      echo "<td>".__('Born on','kid-info-widget').":<br />".date("d-m-Y H:i", $birthDate)."</td></tr>";
      if($show_birth_weight!='') {
          echo "<tr><td>".$birth_weight.__('gram','kid-info-widget')."</td></tr>";
      }
      if($show_birth_length!='') {
      echo "<tr><td>".$birth_length.__('cm','kid-info-widget')."</td></tr>";
      }
      echo "<tr><td>";
      #printAge($difference);
      echo " (".$nrWeeksPassed." ".__('weeks').")</td></tr>";
      echo "<tr><td>".__('Age').": ";
      if($age['year'] > 0) {
         echo $age['year']." ".__('year').", ";
      }
      if($age['month'] > 0) {
         echo $age['month']." ".__('months').", ";
      }
      if($age['day'] > 0) {
        echo $age['day']." ".__('days');
      }
      echo "</td></tr>";
      echo "</table>";	  
      # Now show the content of the widget...
      echo $content;
      echo "</div>";
      # After the widget
      echo $after_widget;
  }

  
  /**
    * Saves the widgets settings.
    *
    */
    function update($new_instance, $old_instance){
      $instance = $old_instance;
      $instance['name'] = strip_tags(stripslashes($new_instance['name']));
      // we want to allow people to put html in this field
      $instance['content'] = $new_instance['content'];
      $instance['date_of_birth'] = strip_tags(stripslashes($new_instance['date_of_birth']));
      $instance['time_of_birth'] = strip_tags(stripslashes($new_instance['time_of_birth']));
      $instance['birth_weight'] = strip_tags(stripslashes($new_instance['birth_weight']));
      $instance['birth_length'] = strip_tags(stripslashes($new_instance['birth_length']));
      $instance['current_weight'] = strip_tags(stripslashes($new_instance['current_weight']));
      $instance['current_length'] = strip_tags(stripslashes($new_instance['current_length']));
      $instance['show_birth_weight'] = $new_instance['show_birth_weight'];
      $instance['show_birth_length'] = $new_instance['show_birth_weight'];
      $instance['show_current_weight'] = $new_instance['show_current_weight'];
      $instance['show_current_length'] = $new_instance['show_current_length'];
      $instance['photo_url'] = $new_instance['photo_url'];
      $instance['photo_width'] = $new_instance['photo_width'];

    return $instance;
  }

  /**
    * Creates the edit form for the widget.
    *
    */
    function form($instance){
      //Defaults
      $instance = wp_parse_args( (array) $instance, array('name'=>'', 'content'=>'', 'date_of_birth'=>'','time_of_birth'=>'', 'birth_weight'=>'','birth_length'=>'') );

      $name = htmlspecialchars($instance['name']);
      $content = htmlspecialchars($instance['content']);
      $date_of_birth = htmlspecialchars($instance['date_of_birth']);
      $time_of_birth = htmlspecialchars($instance['time_of_birth']);
      $birth_weight = htmlspecialchars($instance['birth_weight']);
      $birth_length = htmlspecialchars($instance['birth_length']);
      $current_weight = htmlspecialchars($instance['current_weight']);
      $current_length = htmlspecialchars($instance['current_length']);
      $show_birth_weight = $instance['show_birth_weight'];
      $show_birth_length = $instance['show_birth_length'];
      $show_current_weight = $instance['show_current_weight'];
      $show_current_length = $instance['show_current_length'];

      $photo_url = $instance['photo_url'];
      $photo_width = $instance['photo_width'];

      # Output the options
      # title
      echo '<p style="text-align:right;"><label for="' . $this->get_field_name('name') . '">' . __('Name') . ': <input style="width: 200px;" id="' . $this->get_field_id('name') . '" name="' . $this->get_field_name('name') . '" type="text" value="' . $name . '" /></label></p>';
      # content
      echo '<p style="text-align:right;"><label for="' . $this->get_field_name('content') . '">' . __('Content') . ': <textarea rows="6" cols="40" style="width: 200px;" id="' . $this->get_field_id('content') . '" name="' . $this->get_field_name('content') . '" >' . $content . '</textarea></label></p>';
	#photo_url
 echo '<p style="text-align:right;"><label for="' . $this->get_field_name('photo_url') . '">' . __('Photo url') . ': <input style="width: 200px;" id="' . $this->get_field_id('photo_url') . '" name="' . $this->get_field_name('photo_url') . '" type="text" value="' . $photo_url . '" /></label></p>';
  

      # date
      echo '<p style="text-align:right;"><label for="' . $this->get_field_name('date_of_birth') . '">' . __('Date of birth').' (YYYY-MM-DD):' . ' <input style="width: 200px;" id="' . $this->get_field_id('date_of_birth') . '" name="' . $this->get_field_name('date_of_birth') . '" type="text" value="' . $date_of_birth . '" /></label></p>';
      echo '<p style="text-align:right;"><label for="' . $this->get_field_name('time_of_birth') . '">' . __('Time of birth').' (HH:MM):' . ' <input style="width: 200px;" id="' . $this->get_field_id('time_of_birth') . '" name="' . $this->get_field_name('time_of_birth') . '" type="text" value="' . $time_of_birth . '" /></label></p>';

 
     # weight
       if($show_birth_weight!='') {
           $checked = "checked='checked'";
       } else {
           $checked = "";
       }
 	echo '<input type="checkbox" name="'.$this->get_field_name('show_birth_weight').'" value="true" '.$checked.' />';
	echo '<label for="' . $this->get_field_name('show_birth_weight').'">'. _e('Show birth weight','kid-info-widget').'</label>';
      echo '<p style="text-align:right;"><label for="' . $this->get_field_name('birth_weight') . '">' . __('Birth weight').': ' . __('(gram)','kid-info-widget').' <input style="width: 200px;" id="' . $this->get_field_id('birth_weight') . '" name="' . $this->get_field_name('birth_weight') . '" type="text" value="' . $birth_weight . '" /></label></p>';
  
      # length
       if($show_birth_length!='') {
           $checked = "checked='checked'";
       } else {
           $checked = "";
       }
 	echo '<input type="checkbox" name="'.$this->get_field_name('show-birth-length').'" value="true" '.$checked.' />';
	echo '<label for="' . $this->get_field_name('show_birth_length').'">'. _e('Show birth length','kid-info-widget').'</label>';

      echo '<p style="text-align:right;"><label for="' . $this->get_field_name('birth_length') . '">' . __('Birth length') . ': <input style="width: 200px;" id="' . $this->get_field_id('birth_length') . '" name="' . $this->get_field_name('birth_length') . '" type="text" value="' . $birth_length . '" /></label></p>';

      # currentweight
       if($show_current_weight!='') {
           $checked = "checked='checked'";
       } else {
           $checked = "";
       }
 	echo '<input type="checkbox" name="'.$this->get_field_name('show_current_weight').'" value="true" '.$checked.' />';
	echo '<label for="' . $this->get_field_name('show_current_weight').'">'. _e('Show current weight','kid-info-widget').'</label>';

      echo '<p style="text-align:right;"><label for="' . $this->get_field_name('current_weight') . '">' . __('Weight').': ' . __('(gram)','kid-info-widget').' <input style="width: 200px;" id="' . $this->get_field_id('current_weight') . '" name="' . $this->get_field_name('current_weight') . '" type="text" value="' . $current_weight . '" /></label></p>';
  
      # length
       if($show_current_length!='') {
           $checked = "checked='checked'";
       } else {
           $checked = "";
       }

 	echo '<input type="checkbox" name="'.$this->get_field_name('show_current_length').'" value="true" '.$checked.' />';
	echo '<label for="' . $this->get_field_name('show_current_length').'">'. _e('Show current length','kid-info-widget').'</label>';
      echo '<p style="text-align:right;"><label for="' . $this->get_field_name('current_length') . '">' . __('Length') . ': <input style="width: 200px;" id="' . $this->get_field_id('current_length') . '" name="' . $this->get_field_name('current_length') . '" type="text" value="' . $current_length . '" /></label></p>';

  }

}// END class

 function printAge($ageArray) {
	if($ageArray[0] > 0) {
		echo $ageArray[0] .' '. __('year');
	}
	if($ageArray[1] > 0) {
		echo $ageArray[1] .' '. __('month(s)');
	}
	if($ageArray[1] > 0) {
		echo $ageArray[2] .' '. __('day(s)');
	}

  }


function calculateAge($birthDate) {

$birth['year']     = date('Y',$birthDate);
$birth['month']     = date('n', $birthDate);
$birth['day']     = date('j',$birthDate);
$birth['hour']     = date('G',$birthDate);
$birth['minute']     = date('i',$birthDate);


if ($birth['minute'] > date("i"))            
    {
    $total['minute'] = (60 - $birth['minute'] + date("i"));
    $total['hour'] = -1;
    }
else
    {
    $total['minute'] = (date("i") - $birth['minute']);
    }

if ($birth['hour'] > date("H"))
    {
    $total['hour'] = ($total['hour'] + (24 - $birth['hour'] + date("H")));
    $total['day'] = -1;
    }
else
    {
    $total['hour'] = ($total['hour'] + (date("H") - $birth['hour']));
    }

if ($birth['day'] > date("d"))
    {
    $total['day'] = ($total['day'] + (date("t",mktime(00,00,00,(date("m") - 1),01,date("Y"))) - $birth['day'] + date("d")));
    $total['month'] = -1;
    }
else
    {
    $total['day'] = ($total['day'] + (date("d") - $birth['day']));
    }

if ($birth['month'] > date("m"))
    {
    $total['month'] = ($total['month'] + (12 - $birth['month'] + date("m")));
    $total['year'] = -1;
    }
else
    {
    $total['month'] = ($total['month'] + (date("m") - $birth['month']));
    }

$total['year'] = ($total['year'] + (date("Y") - $birth['year']));

return $total;
}

function dateDifference($startDate, $endDate) 
        { 
            #$startDate = strtotime($startDate); 
            #$endDate = strtotime($endDate); 
            if ($startDate === false || $startDate < 0 || $endDate === false || $endDate < 0 || $startDate > $endDate) 
                return false; 
                
            $years = date('Y', $endDate) - date('Y', $startDate); 
            
            $endMonth = date('m', $endDate); 
            $startMonth = date('m', $startDate); 
            
            // Calculate months 
            $months = $endMonth - $startMonth; 
            if ($months <= 0)  { 
                $months += 12; 
                $years--; 
            } 
            if ($years < 0) 
                return false; 
            
            // Calculate the days 
                        $offsets = array(); 
                        if ($years > 0) 
                            $offsets[] = $years . (($years == 1) ? ' year' : ' years'); 
                        if ($months > 0) 
                            $offsets[] = $months . (($months == 1) ? ' month' : ' months'); 
                        $offsets = count($offsets) > 0 ? '+' . implode(' ', $offsets) : 'now'; 

                        $days = $endDate - strtotime($offsets, $startDate); 
                        $days = date('z', $days);    
                        
            return array($years, $months, $days); 
        } 




/**
  * Register Kid Info Widget
  *
  * Calls 'widgets_init' action after the Kid Info widget has been registered.
  */
  function KidInfoInit() {
  register_widget('KidInfoWidget');
  }
  add_action('widgets_init', 'KidInfoInit');
$plugin_dir = basename(dirname(__FILE__));
load_plugin_textdomain( "kid-info-widget", null, $plugin_dir );

  if(!load_plugin_textdomain('kid-info-widget','/wp-content/languages/')) {
	load_plugin_textdomain('kid-info-widget','/wp-content/plugins/kid-info-widget/');
  }
?>